package App::Bootstrap::Perl;
# git description: v0.04-2-gbf204c8

BEGIN {
  $App::Bootstrap::Perl::AUTHORITY = 'cpan:SCHWIGON';
}
{
  $App::Bootstrap::Perl::VERSION = '0.05';
}
# ABSTRACT: Bootstrap Perl inclusive CPAN from git

1;



=pod

=encoding utf-8

=head1 NAME

App::Bootstrap::Perl - Bootstrap Perl inclusive CPAN from git

=head1 ABOUT

L<bootstrap-perl|bootstrap-perl> can compile and setup a complete Perl
environment from git, inclusive initial CPAN setup with distroprefs to
ensure completely unattended installation.

=head1 AUTHOR

Steffen Schwigon <ss5@renormalist.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steffen Schwigon.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

